==> haskell-http-api-data-0.5.1-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-7OKDVIHydm2A3RZjZEW5Yf
key:                  http-api-data-0.5.1-7OKDVIHydm2A3RZjZEW5Yf
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  46cedd1e5cf468cd37a358cf85018039
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-7OKDVIHydm2A3RZjZEW5Yf
depends:
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-iso8601-1.1.0.0-8ld7k437uUHJlDKS2SmQb1 base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp bytestring-0.11.5.3
    containers-0.6.7 cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    http-types-0.12.4-3waRWhsRr1C4PfAAAPJbwc
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.6.1-ExWhJUsT8vfDg6Ue7daEJ6 transformers-0.5.6.2
    unordered-containers-0.2.20-vB8Yx6KwyeBrT13JKFJ0i
    uuid-types-1.0.6-IK9rmUh3abeAMAQCKrcsZQ

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-api-data-0.5.1-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-http-api-data.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http-api-data
version:              0.5.1
visibility:           public
id:                   http-api-data-0.5.1-CZpMF0NpgKA2Pio9pIzdsD
key:                  http-api-data-0.5.1-CZpMF0NpgKA2Pio9pIzdsD
license:              BSD-3-Clause
maintainer:           Nickolay Kudasov <nickolay.kudasov@gmail.com>
author:               Nickolay Kudasov <nickolay.kudasov@gmail.com>
stability:            unstable
homepage:             http://github.com/fizruk/http-api-data
synopsis:
    Converting to/from HTTP API data like URL pieces, headers and query parameters.

description:
    This package defines typeclasses used for converting Haskell data types to and from HTTP API data.

    Please see README.md

category:             Web
abi:                  8194c9e68e5153a02a32f037a189ad77
exposed:              True
exposed-modules:
    Web.FormUrlEncoded Web.HttpApiData Web.Internal.FormUrlEncoded
    Web.Internal.HttpApiData

import-dirs:          /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/http-api-data-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http-api-data
hs-libraries:         HShttp-api-data-0.5.1-CZpMF0NpgKA2Pio9pIzdsD
depends:
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH
    attoparsec-iso8601-1.1.0.0-8ld7k437uUHJlDKS2SmQb1 base-4.17.2.1
    base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp bytestring-0.11.5.3
    containers-0.6.7 cookie-0.4.6-4KcZJbma3z5GIFijXOzknm
    hashable-1.4.4.0-Jc2uKL4S7Fl9QLNJZYpfiY
    http-types-0.12.4-HMggM4fmSOHB2iuVefoAXW
    tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C text-2.0.2
    time-compat-1.9.6.1-ExWhJUsT8vfDg6Ue7daEJ6 transformers-0.5.6.2
    unordered-containers-0.2.20-L3M6eILO3KM5ipeNJik2xY
    uuid-types-1.0.6-IK9rmUh3abeAMAQCKrcsZQ

haddock-interfaces:
    /usr/share/doc/haskell-http-api-data/html/http-api-data.haddock

haddock-html:         /usr/share/doc/haskell-http-api-data/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
